==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/en_GB.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Loading preview…",
    "Saved" : "Saved",
    "Admin" : "Admin",
    "a safe home for all your data" : "a safe home for all your data",
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given colour is invalid",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded with success",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Failed to write file to disk." : "Failed to write file to disk.",
    "A PHP extension stopped the file upload." : "A PHP extension stopped the file upload.",
    "No file uploaded" : "No file uploaded",
    "Unsupported image type" : "Unsupported image type",
    "You are already using a custom theme" : "You are already using a custom theme",
    "Theming" : "Theming",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
    "Name" : "Name",
    "Reset to default" : "Reset to default",
    "Web address" : "Web address",
    "Web address https://…" : "Web address https://…",
    "Slogan" : "Slogan",
    "Color" : "Colour",
    "Logo" : "Logo",
    "Upload new logo" : "Upload new logo",
    "Login image" : "Login image",
    "Upload new login background" : "Upload new login background",
    "Remove background image" : "Remove background image",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "reset to default" : "reset to default"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/en_GB.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Loading preview…",
    "Saved" : "Saved",
    "Admin" : "Admin",
    "a safe home for all your data" : "a safe home for all your data",
    "Name cannot be empty" : "Name cannot be empty",
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given legal notice address is too long" : "The given legal notice address is too long",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given colour is invalid",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded" : "No file uploaded",
    "Unsupported image type" : "Unsupported image type",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
    "Theming" : "Theming",
    "Legal notice" : "Legal notice",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
    "Name" : "Name",
    "Reset to default" : "Reset to default",
    "Web link" : "Web link",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Colour",
    "Logo" : "Logo",
    "Upload new logo" : "Upload new logo",
    "Login image" : "Login image",
    "Upload new login background" : "Upload new login background",
    "Remove background image" : "Remove background image",
    "Advanced options" : "Advanced options",
    "Legal notice link" : "Legal notice link",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Upload new header logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload new favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "You are already using a custom theme" : "You are already using a custom theme",
    "reset to default" : "reset to default",
    "Web address" : "Web address",
    "Web address https://…" : "Web address https://…",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded with success",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "Failed to write file to disk." : "Failed to write file to disk.",
    "A PHP extension stopped the file upload." : "A PHP extension stopped the file upload."
},
"nplurals=2; plural=(n != 1);");
